@@ -1,6 +1,6 @@
 package Sparrow;
 
-our $VERSION = '0.0.2';
+our $VERSION = '0.0.3';
 
 1;
 
@@ -43,19 +43,20 @@ ability to run tests remotely over rest API (TODO)
 
 =head1 DEPENDENCIES
 
-git, bash
+git, curl, bash
 
 
 =head1 INSTALL
 
     sudo yum install git
+    sudo yum install curl
     
     cpanm Sparrow
 
 
 =head1 USAGE
 
-These are actions provided by sparrow console client: 
+These are actions provided by sparrow console client:
 
 
 =head2 create a project
@@ -87,9 +88,12 @@ Sparrow plugin is a shareable swat test suite.
 
 One could install sparrow plugin and then run related swat tests, see L<check_site|#run-swat-tests> action.
 
+    echo swat-nginx | https://github.com/melezhik/swat-nginx.git >> ~/sparrow/sparrow.list
     sparrow plg install swat-nginx
     sparrow plg install swat-tomcat
 
+Check L<sparrow-plugins|#sparrow-plugins> section to know more about sparrow plugin configuration.
+
 To see available plugin list say this:
 
 I<sparrow plg list>
@@ -100,13 +104,13 @@ I<sparrow plg list --local>
 
 To see installed plugin info say this:
 
-I<sparrow plg info $plugin_name> - NOT IMPLIMENTED YET
+I<sparrow plg info $plugin_name>
 
 To update installed plugin:
 
-*sparrow plg update $plugin_name
+I<sparrow plg update $plugin_name>
 
-This command simple execute `git pull' for clonned git repository 
+This command simple execute `git pull' for cloned git repository
 
 For example:
 
@@ -125,16 +129,16 @@ For example:
 
 I<sparrow project $project_name add_plg $plugin_name>
 
-Swat project could I<link> to one or more plugins. 
+Swat project could I<link> to one or more plugins.
 
-That means one may run different swat test sutes represented by plugins against project's sites.
+That means one may run different swat test suites represented by plugins against project's sites.
 
 So linked plugins could be run against sites in sparrow project.
 
     sparrow project foo add_plg nginx
     sparrow project foo add_plg tomcat
     
-    # and then add some sites 
+    # and then add some sites
 
 
 =head2 create sites
@@ -147,7 +151,7 @@ Sparrow site have a name and base URL.
 
 Site's base URL is root http URL to send http requests to when running swat test suites against a site.
 
-Base URL should be curl compliant. 
+Base URL should be curl compliant.
 
 Add_site command examples:
 
@@ -173,23 +177,24 @@ Check_site command examples:
 
 =head2 customize swat settings for site
 
-*sparrow project $project_name swat_setup $site_name 
+I<sparrow project $project_name swat_setup $site_name>
 
 Swat_setup action allow to customize swat settings, using swat.ini file format.
 
 This command setups L<swat ini file|https://github.com/melezhik/swat#swat-ini-files> for given site .
 
+    export EDITOR=nano
     sparrow project foo swat_setup nginx_proxy
     
         port=88
-        prove_options='-sq'    
+        prove_options='-sq'
 
-More information in swat ini files syntax could be found here - L<https://github.com/melezhik/swat#swat-ini-files|https://github.com/melezhik/swat#swat-ini-files>
+More information on swat ini files syntax could be found here - L<https://github.com/melezhik/swat#swat-ini-files|https://github.com/melezhik/swat#swat-ini-files>
 
 
 =head2 run swat tests remotely
 
-NOT IMPLIMENTED YET.
+NOT IMPLEMENTED YET.
 
 I<GET /$project_name/check_site/$site_name/$plugin_name>
 
@@ -209,7 +214,7 @@ Sparrow plugins are shareable swat test suites installed from remote git reposit
 To install sparrow plugins one should configure sparrow plugin list (SPL).
 
 
-=head1 SPARROW PLUGINS LIST 
+=head1 SPARROW PLUGINS LIST
 
 Sparrow plugins list is represented by text file ~/sparrow/sparrow.list
 
@@ -240,7 +245,7 @@ For example:
 
 To install swat-yars plugin one should do following
 
-    # add plugin to SPL 
+    # add plugin to SPL
     echo swat-yars https://github.com/melezhik/swat-yars.git >> ~/sparrow/sparrow.list
     
     # install plugin
@@ -321,7 +326,7 @@ the only minimal requirement is having valid cpanfile on the root directory of y
 For example:
 
     # cat cpanfile
-       
+    
     # yes, we need a swat to run our tests
     require 'swat';
     
@@ -334,7 +339,7 @@ For example:
 To create sparrow plugin:
 
     * create local git repository
-    * create swat tests 
+    * create swat tests
     * swat project root should be current working directory
     * run swat test to ensure that they works fine ( this one is optional but really useful )
     * create cpanfile to declare perl dependencies
